@@ -4,7 +4,7 @@
 #include <mbarcode-qt/plugininterfaces.h>
 #include <mbarcode-qt/pluginaction.h>
 class Plugin;
-class GetOpinionSink: public QObject, public PluginAction
+class GetOpinionSink: public PluginAction
 {
     Q_OBJECT
 
@@ -15,9 +15,10 @@ public:
     QString getName() {return "Informed Individual Get Opinion Sink Plugin";}
     QString getText() {return "Rating from Informed Individual"; }
     QImage getImage();
-    bool isReady() {return true;}
     void clickAction(QWidget *parentWindow);
     void setPlugin(Plugin *plugin);
+signals:
+    void isReady();
 private:
     Plugin *plugin;
     QImage image;
