@@ -5,7 +5,7 @@
 #include <mbarcode-qt/plugininterfaces.h>
 #include <mbarcode-qt/pluginaction.h>
 class Plugin;
-class GiveOpinionSink : public QObject, public PluginAction
+class GiveOpinionSink : public PluginAction
 {
     Q_OBJECT
 
@@ -16,9 +16,10 @@ public:
     QString getName() {return "Informed Individual Give Opinion Sink Plugin";}
     QString getText() {return "Give Opinion with Informed Individual"; }
     QImage getImage();
-    bool isReady() {return true;}
     void clickAction(QWidget *parentWindow);
     void setPlugin(Plugin *plugin);
+signals:
+    void isReady();
 private:
     Plugin *plugin;
     QImage image;
