@@ -17,10 +17,10 @@ class Plugin : public QObject, public PluginInterface
     Q_OBJECT
     Q_INTERFACES(PluginInterface)
 public:
-    void initInterface(MainWindow *parent);
-    QSet<SinkPlugin*> getSinkPlugins();
+    void initInterface(QWidget *parent);
+    QSet<PluginAction*> getPluginActions();
     QString getName() {return "Informed Individual";}
-    bool hasSettingsWindow() {return true;};
+    bool hasSettingsWindow() {return true;}
     QMainWindow* getSettingsWindow(QWidget *parent);
 
     enum NextAction {GetOpinion, GiveOpinion};
